# Security Policy

## Reporting a Vulnerability

Please do not open public GitHub issues for security vulnerabilities.

Report suspected vulnerabilities to `hello@super-agentic.ai` with:

- a clear description of the issue
- reproduction steps or a proof of concept
- the affected version or commit
- any suggested mitigations if available

We will acknowledge reports as quickly as practical and coordinate remediation and disclosure with the reporter.

## Supported Versions

Security fixes are prioritized for the latest published release and the current `main` branch.
